==> quao-0.3.1.tar.gz: quao-0.3.1/src/quao/model/device/quao_device.py <==
"""
    QuaO Project quao_device.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""
from qiskit import transpile
from qiskit import QiskitError

from ...enum.job_status import JobStatus
from ...enum.processing_unit import ProcessingUnit
from ...util.json_parser_util import JsonParserUtils
from ...enum.sdk import Sdk
from ..device.device import Device
from ..provider.provider import Provider
from ...config.logging_config import *


class QuaoDevice(Device):
    def _get_name(self) -> str:
        return str(self.device.configuration().backend_name)

    def __init__(self, provider: Provider, device_specification: str, sdk: str):
        super().__init__(provider, device_specification)
        self.sdk = sdk

    def _create_job(self, circuit, shots):
        logger.debug('Create Quao job with {0} shots'.format(shots))
        if Sdk.QISKIT.value.__eq__(self.sdk):
            self.device.set_options(device=ProcessingUnit.GPU.value, shots=shots)
            transpiled_circuit = transpile(circuits=circuit, backend=self.device)

            return self.device.run(transpiled_circuit)

        if Sdk.BRAKET.value.__eq__(self.sdk):
            import time

            start_time = time.time()

            job = self.device.run(task_specification=circuit, shots=shots)

            self.execution_time = time.time() - start_time

            return job

        raise Exception("Sdk not supported!")

    def _is_simulator(self) -> bool:
        return True

    def _parse_job_result(self, job_result) -> dict:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return JsonParserUtils.parse(job_result.to_dict())

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return JsonParserUtils.parse(job_result.__dict__)

    def _produce_histogram_data(self, job_result) -> dict:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            try:
                histogram_data = job_result.get_counts()
            except QiskitError as qiskit_error:
                logger.debug("Can't produce histogram with error: {0}".format(str(qiskit_error)))
                histogram_data = None

            return histogram_data

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return dict(job_result.measurement_counts)

    def _get_provider_job_id(self, job) -> str:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return job.job_id()

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return job.id

    def _get_job_status(self, job) -> str:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return job.status().name

        if Sdk.BRAKET.value.__eq__(self.sdk):
            job_state = job.state()
            if JobStatus.COMPLETED.value.__eq__(job_state):
                job_state = JobStatus.DONE.value
            return job_state

    def _get_execution_time(self, job_result):
        if Sdk.QISKIT.value.__eq__(self.sdk):
            metadata = job_result['metadata']

            if metadata is None or not bool(metadata):
                return self.execution_time

            return metadata['time_taken_execute']

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return self.execution_time

==> quao-0.3.26.tar.gz: quao-0.3.26/src/quao/model/device/quao_device.py <==
"""
    QuaO Project quao_device.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""
from qiskit import transpile
from qiskit import QiskitError

from ...enum.job_status import JobStatus
from ...enum.processing_unit import ProcessingUnit
from ...enum.sdk import Sdk
from ..device.device import Device
from ..provider.provider import Provider
from ...config.logging_config import *


class QuaoDevice(Device):
    def _get_name(self) -> str:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return str(self.device.configuration().backend_name)

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return str(self.device.name)

        raise Exception("Sdk not supported!")

    def __init__(self, provider: Provider, device_specification: str, sdk: str):
        super().__init__(provider, device_specification)
        self.sdk = sdk

    def _create_job(self, circuit, shots):
        logger.debug('Create Quao job with {0} shots'.format(shots))
        if Sdk.QISKIT.value.__eq__(self.sdk):
            self.device.set_options(device=ProcessingUnit.GPU.value, shots=shots)
            transpiled_circuit = transpile(circuits=circuit, backend=self.device)

            return self.device.run(transpiled_circuit)

        if Sdk.BRAKET.value.__eq__(self.sdk):
            import time

            start_time = time.time()

            job = self.device.run(task_specification=circuit, shots=shots)

            self.execution_time = time.time() - start_time

            return job

        raise Exception("Sdk not supported!")

    def _is_simulator(self) -> bool:
        return True

    def _produce_histogram_data(self, job_result) -> dict:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            try:
                histogram_data = job_result.get_counts()
            except QiskitError as qiskit_error:
                logger.debug("Can't produce histogram with error: {0}".format(str(qiskit_error)))
                histogram_data = None

            return histogram_data

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return dict(job_result.measurement_counts)

    def _get_provider_job_id(self, job) -> str:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return job.job_id()

        if Sdk.BRAKET.value.__eq__(self.sdk):
            return job.id

    def _get_job_status(self, job) -> str:
        if Sdk.QISKIT.value.__eq__(self.sdk):
            return job.status().name

        if Sdk.BRAKET.value.__eq__(self.sdk):
            job_state = job.state()
            if JobStatus.COMPLETED.value.__eq__(job_state):
                job_state = JobStatus.DONE.value
            return job_state

    def _calculate_execution_time(self, job_result):
        if Sdk.QISKIT.value.__eq__(self.sdk):
            if 'metadata' not in job_result:
                return

            metadata = job_result['metadata']

            if metadata is None \
                    or not bool(metadata)\
                    or 'time_taken_execute' not in metadata:
                return

            self.execution_time = metadata['time_taken_execute']
